==> kubernetes-model-networking-5.0.3-sources.jar: annotations/io/fabric8/kubernetes/api/model/networking/v1beta1/HTTPIngressPathFluentImpl.java <==
package io.fabric8.kubernetes.api.model.networking.v1beta1;

import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

public class HTTPIngressPathFluentImpl<A extends io.fabric8.kubernetes.api.model.networking.v1beta1.HTTPIngressPathFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.networking.v1beta1.HTTPIngressPathFluent<A> {

    private io.fabric8.kubernetes.api.model.networking.v1beta1.IngressBackendBuilder backend;
    private String path;
    private String pathType;

    public HTTPIngressPathFluentImpl() {
    }

    public HTTPIngressPathFluentImpl(io.fabric8.kubernetes.api.model.networking.v1beta1.HTTPIngressPath instance) {
        this.withBackend(instance.getBackend()); 
        this.withPath(instance.getPath()); 
        this.withPathType(instance.getPathType()); 
    }

    
/**
 * This method has been deprecated, please use method buildBackend instead.
 * @return The buildable object.
 */
@Deprecated public io.fabric8.kubernetes.api.model.networking.v1beta1.IngressBackend getBackend() {
        return this.backend!=null?this.backend.build():null;
    }

    public io.fabric8.kubernetes.api.model.networking.v1beta1.IngressBackend buildBackend() {
        return this.backend!=null?this.backend.build():null;
    }

    public A withBackend(io.fabric8.kubernetes.api.model.networking.v1beta1.IngressBackend backend) {
        _visitables.get("backend").remove(this.backend);
        if (backend!=null){ this.backend= new io.fabric8.kubernetes.api.model.networking.v1beta1.IngressBackendBuilder(backend); _visitables.get("backend").add(this.backend);} return (A) this;
    }

    public Boolean hasBackend() {
        return this.backend != null;
    }

    public HTTPIngressPathFluent.BackendNested<A> withNewBackend() {
        return new BackendNestedImpl();
    }

    public HTTPIngressPathFluent.BackendNested<A> withNewBackendLike(io.fabric8.kubernetes.api.model.networking.v1beta1.IngressBackend item) {
        return new BackendNestedImpl(item);
    }

    public HTTPIngressPathFluent.BackendNested<A> editBackend() {
        return withNewBackendLike(getBackend());
    }

    public HTTPIngressPathFluent.BackendNested<A> editOrNewBackend() {
        return withNewBackendLike(getBackend() != null ? getBackend(): new io.fabric8.kubernetes.api.model.networking.v1beta1.IngressBackendBuilder().build());
    }

    public HTTPIngressPathFluent.BackendNested<A> editOrNewBackendLike(io.fabric8.kubernetes.api.model.networking.v1beta1.IngressBackend item) {
        return withNewBackendLike(getBackend() != null ? getBackend(): item);
    }

    public String getPath() {
        return this.path;
    }

    public A withPath(String path) {
        this.path=path; return (A) this;
    }

    public Boolean hasPath() {
        return this.path != null;
    }

    public A withNewPath(String arg1) {
        return (A)withPath(new String(arg1));
    }

    public A withNewPath(StringBuilder arg1) {
        return (A)withPath(new String(arg1));
    }

    public A withNewPath(StringBuffer arg1) {
        return (A)withPath(new String(arg1));
    }

    public String getPathType() {
        return this.pathType;
    }

    public A withPathType(String pathType) {
        this.pathType=pathType; return (A) this;
    }

    public Boolean hasPathType() {
        return this.pathType != null;
    }

    public A withNewPathType(String arg1) {
        return (A)withPathType(new String(arg1));
    }

    public A withNewPathType(StringBuilder arg1) {
        return (A)withPathType(new String(arg1));
    }

    public A withNewPathType(StringBuffer arg1) {
        return (A)withPathType(new String(arg1));
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        HTTPIngressPathFluentImpl that = (HTTPIngressPathFluentImpl) o;
        if (backend != null ? !backend.equals(that.backend) :that.backend != null) return false;
        if (path != null ? !path.equals(that.path) :that.path != null) return false;
        if (pathType != null ? !pathType.equals(that.pathType) :that.pathType != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(backend,  path,  pathType,  super.hashCode());
    }

    public class BackendNestedImpl<N> extends io.fabric8.kubernetes.api.model.networking.v1beta1.IngressBackendFluentImpl<HTTPIngressPathFluent.BackendNested<N>> implements HTTPIngressPathFluent.BackendNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final io.fabric8.kubernetes.api.model.networking.v1beta1.IngressBackendBuilder builder;

            BackendNestedImpl(io.fabric8.kubernetes.api.model.networking.v1beta1.IngressBackend item) {
                this.builder = new io.fabric8.kubernetes.api.model.networking.v1beta1.IngressBackendBuilder(this, item);
                        
            }

            BackendNestedImpl() {
                this.builder = new io.fabric8.kubernetes.api.model.networking.v1beta1.IngressBackendBuilder(this);
                        
            }

            public N and() {
                return (N) HTTPIngressPathFluentImpl.this.withBackend(builder.build());
            }

            public N endBackend() {
                return and();
            }
    }


}

==> kubernetes-model-networking-5.3.0-sources.jar: annotations/io/fabric8/kubernetes/api/model/networking/v1beta1/HTTPIngressPathFluentImpl.java <==
package io.fabric8.kubernetes.api.model.networking.v1beta1;

import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

public class HTTPIngressPathFluentImpl<A extends io.fabric8.kubernetes.api.model.networking.v1beta1.HTTPIngressPathFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.networking.v1beta1.HTTPIngressPathFluent<A> {

    private io.fabric8.kubernetes.api.model.networking.v1beta1.IngressBackendBuilder backend;
    private String path;
    private String pathType;

    public HTTPIngressPathFluentImpl() {
    }

    public HTTPIngressPathFluentImpl(io.fabric8.kubernetes.api.model.networking.v1beta1.HTTPIngressPath instance) {
        this.withBackend(instance.getBackend()); 
        this.withPath(instance.getPath()); 
        this.withPathType(instance.getPathType()); 
    }

    
/**
 * This method has been deprecated, please use method buildBackend instead.
 * @return The buildable object.
 */
@Deprecated public io.fabric8.kubernetes.api.model.networking.v1beta1.IngressBackend getBackend() {
        return this.backend!=null?this.backend.build():null;
    }

    public io.fabric8.kubernetes.api.model.networking.v1beta1.IngressBackend buildBackend() {
        return this.backend!=null?this.backend.build():null;
    }

    public A withBackend(io.fabric8.kubernetes.api.model.networking.v1beta1.IngressBackend backend) {
        _visitables.get("backend").remove(this.backend);
        if (backend!=null){ this.backend= new io.fabric8.kubernetes.api.model.networking.v1beta1.IngressBackendBuilder(backend); _visitables.get("backend").add(this.backend);} return (A) this;
    }

    public Boolean hasBackend() {
        return this.backend != null;
    }

    public HTTPIngressPathFluent.BackendNested<A> withNewBackend() {
        return new BackendNestedImpl();
    }

    public HTTPIngressPathFluent.BackendNested<A> withNewBackendLike(io.fabric8.kubernetes.api.model.networking.v1beta1.IngressBackend item) {
        return new BackendNestedImpl(item);
    }

    public HTTPIngressPathFluent.BackendNested<A> editBackend() {
        return withNewBackendLike(getBackend());
    }

    public HTTPIngressPathFluent.BackendNested<A> editOrNewBackend() {
        return withNewBackendLike(getBackend() != null ? getBackend(): new io.fabric8.kubernetes.api.model.networking.v1beta1.IngressBackendBuilder().build());
    }

    public HTTPIngressPathFluent.BackendNested<A> editOrNewBackendLike(io.fabric8.kubernetes.api.model.networking.v1beta1.IngressBackend item) {
        return withNewBackendLike(getBackend() != null ? getBackend(): item);
    }

    public String getPath() {
        return this.path;
    }

    public A withPath(String path) {
        this.path=path; return (A) this;
    }

    public Boolean hasPath() {
        return this.path != null;
    }

    public A withNewPath(StringBuilder arg1) {
        return (A)withPath(new String(arg1));
    }

    public A withNewPath(int[] arg1,int arg2,int arg3) {
        return (A)withPath(new String(arg1, arg2, arg3));
    }

    public A withNewPath(char[] arg1) {
        return (A)withPath(new String(arg1));
    }

    public A withNewPath(StringBuffer arg1) {
        return (A)withPath(new String(arg1));
    }

    public A withNewPath(byte[] arg1,int arg2) {
        return (A)withPath(new String(arg1, arg2));
    }

    public A withNewPath(byte[] arg1) {
        return (A)withPath(new String(arg1));
    }

    public A withNewPath(char[] arg1,int arg2,int arg3) {
        return (A)withPath(new String(arg1, arg2, arg3));
    }

    public A withNewPath(byte[] arg1,int arg2,int arg3) {
        return (A)withPath(new String(arg1, arg2, arg3));
    }

    public A withNewPath(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withPath(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewPath(String arg1) {
        return (A)withPath(new String(arg1));
    }

    public String getPathType() {
        return this.pathType;
    }

    public A withPathType(String pathType) {
        this.pathType=pathType; return (A) this;
    }

    public Boolean hasPathType() {
        return this.pathType != null;
    }

    public A withNewPathType(StringBuilder arg1) {
        return (A)withPathType(new String(arg1));
    }

    public A withNewPathType(int[] arg1,int arg2,int arg3) {
        return (A)withPathType(new String(arg1, arg2, arg3));
    }

    public A withNewPathType(char[] arg1) {
        return (A)withPathType(new String(arg1));
    }

    public A withNewPathType(StringBuffer arg1) {
        return (A)withPathType(new String(arg1));
    }

    public A withNewPathType(byte[] arg1,int arg2) {
        return (A)withPathType(new String(arg1, arg2));
    }

    public A withNewPathType(byte[] arg1) {
        return (A)withPathType(new String(arg1));
    }

    public A withNewPathType(char[] arg1,int arg2,int arg3) {
        return (A)withPathType(new String(arg1, arg2, arg3));
    }

    public A withNewPathType(byte[] arg1,int arg2,int arg3) {
        return (A)withPathType(new String(arg1, arg2, arg3));
    }

    public A withNewPathType(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withPathType(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewPathType(String arg1) {
        return (A)withPathType(new String(arg1));
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        HTTPIngressPathFluentImpl that = (HTTPIngressPathFluentImpl) o;
        if (backend != null ? !backend.equals(that.backend) :that.backend != null) return false;
        if (path != null ? !path.equals(that.path) :that.path != null) return false;
        if (pathType != null ? !pathType.equals(that.pathType) :that.pathType != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(backend,  path,  pathType,  super.hashCode());
    }

    public class BackendNestedImpl<N> extends io.fabric8.kubernetes.api.model.networking.v1beta1.IngressBackendFluentImpl<HTTPIngressPathFluent.BackendNested<N>> implements HTTPIngressPathFluent.BackendNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final io.fabric8.kubernetes.api.model.networking.v1beta1.IngressBackendBuilder builder;

            BackendNestedImpl(io.fabric8.kubernetes.api.model.networking.v1beta1.IngressBackend item) {
                this.builder = new io.fabric8.kubernetes.api.model.networking.v1beta1.IngressBackendBuilder(this, item);
                        
            }

            BackendNestedImpl() {
                this.builder = new io.fabric8.kubernetes.api.model.networking.v1beta1.IngressBackendBuilder(this);
                        
            }

            public N and() {
                return (N) HTTPIngressPathFluentImpl.this.withBackend(builder.build());
            }

            public N endBackend() {
                return and();
            }
    }


}
